Learn R Programming

nondetects (version 2.2.0)

nature2008: The qPCR data from McMurray et al. Nature 2008.

Description

A study of the effect of p53 and/or Ras mutations on gene expression. The third dataset is a comparison between four cell types -- YAMC cells, mutant-p53 YAMC cells, activated-Ras YAMC cells, and p53/Ras double mutant YAMC cells. Three replicates were performed for the untransformed YAMC cells, and four replicates were performed for each of the other cell types.

Usage

data(nature2008)

Arguments

Format

A qPCRset object.

Examples

Run this code
 data(nature2008)
 show(nature2008)

Run the code above in your browser using DataLab