Usage
qpcrImpute(object, dj=NULL, pyfit=NULL, groupVars=NULL, batch=NULL, tol=1, iterMax=100, outform=c("Single","Param","Multy"), vary_fit=TRUE, vary_model=TRUE, add_noise=TRUE, formula=NULL, numsam=5)
Arguments
dj
normalization values. If NULL, features with "control"
in featureType(object) are used to normalize the data. If no control
features are found, the data are not normalized.
pyfit
initial estimate of the relationship between the
probability of a non-detect and average expression. If NULL, this
relationship is estimated from the data.
groupVars
which columns in pData(object) should be used to
determine replicate samples. If NULL, all columns are used.
batch
matrix with batch effects, it has the same dimentions as exprs(object). If NULL, batch effect matrix is a zero matrix.
tol
likelihood convergence criterion of the EM algorithm.
iterMax
maximimum number of iterations of the EM algorithm.
outform
the form of the output requested.If "Single" performes a single imputation of missing values. If "Param" returnes estimated model parameters: mean and variance. If "Multy" performes a multiple imputation of missing values, and creats multiple data sets with imputed values.
formula
specifies the model.
numsam
number of the datasets to be created if outform="Multy". The default value is 5.
vary_fit
if outform="Multy", includes the model uncertainty due to the logit of the probability of being missing. The default value is "TRUE".
vary_model
if outform="Multy", includes the model uncertainty due to the estimating mean of the data. The default value is "TRUE".
add_noise
if outform="Multy", introduses the variance component due to the random noise. The default value is "TRUE".