Learn R Programming

nondetects (version 2.2.0)

sagmb2011: The qPCR data from Almudevar et al. SAGMB 2011.

Description

Cells transformed to malignancy by mutant p53 and activated Ras are perturbed with the aim of restoring gene expression to levels found in non-transformed parental cells via retrovirus-mediated re-expression of corresponding cDNAs or shRNA-dependent stable knock-down. The data contain 4-6 replicates for each perturbation, and each perturbation has a corresponding control sample in which only the vector has been added.

Usage

data(sagmb2011)

Arguments

Format

A qPCRset object.

Examples

Run this code
 data(sagmb2011)
 show(sagmb2011)

Run the code above in your browser using DataLab